
==================================
Welcome to Caplena's Documentation
==================================

This site covers Caplena's usage & API documentation. To learn more about what you 
can use  Caplena for and how to create your own API key, please see 
`our main website <https://caplena.com>`_.

Getting Started
---------------

If you are trying to get started as quickly as possible, this part of the
documentation is for you.

.. toctree::
  :maxdepth: 3

  getting-started

Creating Projects and adding rows
---------------

Learn how to create projects and upload your data to Caplena.

.. toctree::
  :maxdepth: 3

  creating-projects

Retrieving Projects and results
---------------

Understand how to fetch previously uploaded data and how to access
the results of the analysis performed by Caplena.

.. toctree::
  :maxdepth: 3

  retrieving-results


API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
  :maxdepth: 2

  api-reference